@@ -1,6 +1,6 @@
 /* query-editor.h
  *
- * Copyright (C) 2002 Vivien Malerba
+ * Copyright (C) 2004 Vivien Malerba
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -21,8 +21,9 @@
 #ifndef __QUERY_EDITOR__
 #define __QUERY_EDITOR__
 
+#include <gtk/gtk.h>
+#include <libgnomedb/libgnomedb.h>
 #include <gnome.h>
-#include "query.h"
 
 G_BEGIN_DECLS
 
@@ -32,42 +33,34 @@ G_BEGIN_DECLS
 #define IS_QUERY_EDITOR(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, query_editor_get_type ())
 
 
-typedef struct _QueryEditor QueryEditor;
+typedef struct _QueryEditor      QueryEditor;
 typedef struct _QueryEditorClass QueryEditorClass;
+typedef struct _QueryEditorPriv  QueryEditorPriv;
 
 
 /* struct for the object's data */
 struct _QueryEditor
 {
-	GtkVBox        object;
+	GtkVBox          object;
 
-	Query         *query;
-
-	/* Notebook */
-	GtkWidget     *main_nb;
-
-	/* Text buffer for the SQL edition */
-	GtkWidget     *sql_view;
-
-	/* Entry widgets */
-	GtkWidget     *name;
-	GtkWidget     *descr;
-
-	/* Option menu and items */
-	GtkWidget     *option_menu;
-	GSList        *mitems;
+	QueryEditorPriv *priv;
 };
 
 /* struct for the object's class */
 struct _QueryEditorClass
 {
-	GtkVBoxClass parent_class;
+	GtkVBoxClass      parent_class;
 };
 
-/* generic widget's functions */
-guint      query_editor_get_type (void);
-GtkWidget *query_editor_new      (Query *q);
+/* 
+ * Generic widget's methods 
+*/
+guint      query_editor_get_type            (void);
+GtkWidget *query_editor_new                 (GnomeDbQuery *query);
 
 G_END_DECLS
 
 #endif
+
+
+
