@@ -1,6 +1,11 @@
-/* session.h
+/* Mergeant
  *
- * Copyright (C) 1999 - 2001 Vivien Malerba
+ * Copyright (C) 1999 - 2003 Vivien Malerba
+ * Copyright (C) 2002 - 2003 Rodrigo Moya
+ *
+ * Authors:
+ *       Vivien Malerba <malerba@gnome-db.org>
+ *       Rodrigo Moya <rodrigo@gnome-db.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -18,12 +23,9 @@
  * USA
  */
 
-#include <gnome.h>
+#ifndef __SESSION_H__
+#define __SESSION_H__
 
-gint session_die_cb (GnomeClient * client, gpointer client_data);
-gint session_save_state_cb (GnomeClient * client,
-			    gint phase,
-			    GnomeRestartStyle restart_style,
-			    gint shutdown,
-			    GnomeInteractStyle interact_style,
-			    gint fast, gpointer client_data);
+void session_setup (void);
+
+#endif
